@@ -115,6 +115,8 @@ sub edit_account {
 	my $apache2 = shift || die 'Request object required';
 	my $cgi = CGI->new;
 	
+	my $user_table = _gen_user_table($cgi);
+	
 	my $html = $cgi->start_html("Foo");
 	$html .= <<HTML;
 <h1>Bar</h1>
@@ -125,6 +127,35 @@ HTML
 } # edit_account
 
 
+##
+## Support functions
+##
+
+sub _gen_user_table {
+	my $cgi = shift;
+	
+	my $username = $cgi->textfield(-name => 'Username', -size => 12,
+		-maxlength => 12);
+	my $password = $cgi->textfield(-name => 'Username', -size => 12,
+		-maxlength => 12);
+	my $check_pass = $cgi->textfield(-name => 'Username', -size => 12,
+		-maxlength => 12);
+	my $table = <<HTML;
+<table class="form_table" id="user_table">
+  <tr id="username_row"><td class="left">
+    <span class="bold">Choose Your Username:</span><br />
+    <span class="small">(5-12 characters)</span>
+    </td><td class="right">
+  $username
+ </td></tr>
+ 
+ 
+HTML
+	
+	
+} # _gen_user_table
+
+
 
 =head1 AUTHOR
 
